==> ah-formbuilder-1.1.7.tgz: package/es/components/app/fields-wrappers/Video.js <==
var _jsxFileName = "/home/ayesha/Project/formbuilder/src/components/app/fields-wrappers/Video.js";
import React from 'react';
import LinkIcon from '@material-ui/icons/Launch';
export default function VideoWrapper(props) {
  var _this = this;

  var extractVideoId = function extractVideoId(url) {
    // Regular expression to match YouTube video IDs in various URL formats
    var regex = /^(?:https?:\/\/)?(?:www\.)?(?:youtube\.com\/(?:watch\?.*v=|embed\/|v\/)|youtu\.be\/)([\w-]{11})(&(?:.*))?$/; // Match the URL against the regular expression

    var match = url.match(regex);

    if (match && match[1]) {
      return match[1]; // Return the extracted video ID
    }

    return null; // Return null if no match was found
  };

  var renderLink = function renderLink() {
    if (props.data.config.href) {
      return /*#__PURE__*/React.createElement("div", {
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 18,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("a", {
        href: props.data.config.href,
        target: "_blank",
        rel: "noopener noreferrer",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 19,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement(LinkIcon, {
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 20,
          columnNumber: 13
        }
      })), /*#__PURE__*/React.createElement("video", {
        className: "ahfb-width-full",
        autoPlay: !!props.data.config.autoPlay,
        controls: true,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 22,
          columnNumber: 11
        }
      }, /*#__PURE__*/React.createElement("source", {
        src: props.data.config.url,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 23,
          columnNumber: 13
        }
      })));
    } else if (props.data.config.subType === 'youtube') {
      var embeddedUrl = "https://www.youtube.com/embed/" + extractVideoId(props.data.config.url);
      return /*#__PURE__*/React.createElement("iframe", {
        id: "youtube-video",
        className: "ahfb-iframe",
        title: props.data.config.url,
        src: embeddedUrl,
        frameBorder: "0",
        allow: "accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture",
        allowFullScreen: true,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 30,
          columnNumber: 15
        }
      });
    } else {
      return /*#__PURE__*/React.createElement("video", {
        className: "ahfb-width-full",
        controls: true,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 42,
          columnNumber: 9
        }
      }, /*#__PURE__*/React.createElement("source", {
        src: props.data.config.url,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 43,
          columnNumber: 11
        }
      }));
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: props.data.config.subType === 'youtube' ? "afhb-iframe-wrapper" : "ahfb-width-full",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 50,
      columnNumber: 5
    }
  }, renderLink());
}

==> ah-formbuilder-1.2.6.tgz: package/es/components/app/fields-wrappers/Video.js <==
import React from 'react';
import LinkIcon from '@material-ui/icons/Launch';
export default function VideoWrapper(props) {
  var extractVideoId = function extractVideoId(url) {
    // Regular expression to match YouTube video IDs in various URL formats
    var regex = /^(?:https?:\/\/)?(?:www\.)?(?:youtube\.com\/(?:watch\?.*v=|embed\/|v\/)|youtu\.be\/)([\w-]{11})(&(?:.*))?$/;
    // Match the URL against the regular expression
    var match = url.match(regex);
    if (match && match[1]) {
      return match[1]; // Return the extracted video ID
    }
    return null; // Return null if no match was found
  };
  var renderLink = function renderLink() {
    if (props.data.config.href) {
      return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("a", {
        href: props.data.config.href,
        target: "_blank",
        rel: "noopener noreferrer"
      }, /*#__PURE__*/React.createElement(LinkIcon, null)), /*#__PURE__*/React.createElement("video", {
        className: "ahfb-width-full",
        autoPlay: !!props.data.config.autoPlay,
        controls: true
      }, /*#__PURE__*/React.createElement("source", {
        src: props.data.config.url
      })));
    } else if (props.data.config.subType === 'youtube') {
      var embeddedUrl = "https://www.youtube.com/embed/" + extractVideoId(props.data.config.url);
      return /*#__PURE__*/React.createElement("iframe", {
        id: "youtube-video",
        className: "ahfb-iframe",
        title: props.data.config.url,
        src: embeddedUrl,
        frameBorder: "0",
        allow: "accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture",
        allowFullScreen: true
      });
    } else {
      return /*#__PURE__*/React.createElement("video", {
        className: "ahfb-width-full",
        controls: true
      }, /*#__PURE__*/React.createElement("source", {
        src: props.data.config.url
      }));
    }
  };
  return /*#__PURE__*/React.createElement("div", {
    className: props.data.config.subType === 'youtube' ? "afhb-iframe-wrapper" : "ahfb-width-full"
  }, renderLink());
}
